==> dolphin-17.03.80.tar.xz: dolphin-17.03.80/src/settings/additionalinfodialog.h <==
/***************************************************************************
 *   Copyright (C) 2007-2012 by Peter Penz <peter.penz19@gmail.com>        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
 ***************************************************************************/

#ifndef ADDITIONALINFODIALOG_H
#define ADDITIONALINFODIALOG_H

#include <QDialog>
#include <QList>
#include <QListWidget>


/**
 * @brief Dialog for changing the additional information shown in the view.
 */
class AdditionalInfoDialog : public QDialog
{
    Q_OBJECT

public:
    AdditionalInfoDialog(QWidget* parent, const QList<QByteArray>& visibleRoles);
    virtual ~AdditionalInfoDialog();
    QList<QByteArray> visibleRoles() const;

public slots:
    void accept() Q_DECL_OVERRIDE;

private:
    QList<QByteArray> m_visibleRoles;
    QListWidget* m_listWidget;
};

#endif

==> dolphin-18.04.0.tar.xz: dolphin-18.04.0/src/settings/additionalinfodialog.h <==
/***************************************************************************
 *   Copyright (C) 2007-2012 by Peter Penz <peter.penz19@gmail.com>        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
 ***************************************************************************/

#ifndef ADDITIONALINFODIALOG_H
#define ADDITIONALINFODIALOG_H

#include <QDialog>
#include <QList>
#include <QListWidget>

/**
 * @brief Dialog for changing the additional information shown in the view.
 */
class AdditionalInfoDialog : public QDialog
{
    Q_OBJECT

public:
    AdditionalInfoDialog(QWidget* parent, const QList<QByteArray>& visibleRoles);
    ~AdditionalInfoDialog() override;
    QList<QByteArray> visibleRoles() const;

public slots:
    void accept() override;

private:
    QList<QByteArray> m_visibleRoles;
    QListWidget* m_listWidget;
};

#endif
